==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/auth/authorization.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

Authorization = Union[raw.types.auth.Authorization, raw.types.auth.AuthorizationSignUpRequired]


# noinspection PyRedeclaration
class Authorization(TLObject):  # type: ignore
    """This base type has 2 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`auth.Authorization <pyrogram.raw.types.auth.Authorization>`
            - :obj:`auth.AuthorizationSignUpRequired <pyrogram.raw.types.auth.AuthorizationSignUpRequired>`

    See Also:
        This object can be returned by 6 methods:

        .. hlist::
            :columns: 2

            - :obj:`auth.SignUp <pyrogram.raw.functions.auth.SignUp>`
            - :obj:`auth.SignIn <pyrogram.raw.functions.auth.SignIn>`
            - :obj:`auth.ImportAuthorization <pyrogram.raw.functions.auth.ImportAuthorization>`
            - :obj:`auth.ImportBotAuthorization <pyrogram.raw.functions.auth.ImportBotAuthorization>`
            - :obj:`auth.CheckPassword <pyrogram.raw.functions.auth.CheckPassword>`
            - :obj:`auth.RecoverPassword <pyrogram.raw.functions.auth.RecoverPassword>`
    """

    QUALNAME = "pyrogram.raw.base.auth.Authorization"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/auth/authorization.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

Authorization = Union[raw.types.auth.Authorization, raw.types.auth.AuthorizationSignUpRequired]


# noinspection PyRedeclaration
class Authorization:  # type: ignore
    """This base type has 2 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`auth.Authorization <pyrogram.raw.types.auth.Authorization>`
            - :obj:`auth.AuthorizationSignUpRequired <pyrogram.raw.types.auth.AuthorizationSignUpRequired>`

    See Also:
        This object can be returned by 6 methods:

        .. hlist::
            :columns: 2

            - :obj:`auth.SignUp <pyrogram.raw.functions.auth.SignUp>`
            - :obj:`auth.SignIn <pyrogram.raw.functions.auth.SignIn>`
            - :obj:`auth.ImportAuthorization <pyrogram.raw.functions.auth.ImportAuthorization>`
            - :obj:`auth.ImportBotAuthorization <pyrogram.raw.functions.auth.ImportBotAuthorization>`
            - :obj:`auth.CheckPassword <pyrogram.raw.functions.auth.CheckPassword>`
            - :obj:`auth.RecoverPassword <pyrogram.raw.functions.auth.RecoverPassword>`
    """

    QUALNAME = "pyrogram.raw.base.auth.Authorization"
